# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`wordpress`](#wordpress): Install wpcli tool, use it to download wordpress core, create tables in database, configure wordpress and manage plugins and themes.
* [`wordpress::cli`](#wordpresscli): Install wpcli tool.
* [`wordpress::core`](#wordpresscore): use wpcli to download wordpress core, create tables in database and configure wordpress.
* [`wordpress::external_fact`](#wordpressexternal_fact): deploy files to forge an external fact named 'wordpress'
* [`wordpress::params`](#wordpressparams): set defaults values for some variables and parameters.
* [`wordpress::resource`](#wordpressresource): download and manage resources aka plugins and themes.

## Classes

### wordpress

Install wpcli tool, use it to download wordpress core, create tables in database, configure wordpress and manage plugins and themes.

#### Examples

##### Configure one wordpress instance for URL wordpress.foo.org with remote mariadb database inside an already configurer vhosts root '/var/www/wordpress.foo.org'.

```puppet
class { 'wordpress':
  settings => {
    'wordpress.foo.org' => {
      owner         => 'wp',
      dbhost        => 'XX.XX.XX.XX',
      dbname        => 'wordpress',
      dbuser        => 'wpuserdb',
      dbpasswd      => 'kiki',
      wproot        => '/var/www/wordpress.foo.org',
      wptitle       => 'hola this wordpress instance is installed by puppet',
      wpadminuser   => 'wpadmin',
      wpadminpasswd => 'lolo',
      wpadminemail  => 'bar@foo.org',
    }
  }
}
```

#### Parameters

The following parameters are available in the `wordpress` class.

##### `settings`

Data type: `Hash`

Describes all availables settings in this module for all wordpress instances on this node. Defaults to empty hash.

Default value: {}

##### `wpcli_url`

Data type: `Pattern['^http']`

http URL where to download the wpcli tool. Default to 'https://raw.githubusercontent.com/wp-cli/builds/gh-pages/phar/wp-cli.phar'.

Default value: $wordpress::params::default_wpcli_url

##### `wpcli_bin`

Data type: `Pattern['^/']`

The PATH where the wpcli tools is deployed. Defaults to '/usr/local/bin/wp'.

Default value: $wordpress::params::default_wpcli_bin

### wordpress::cli

Install wpcli tool.

#### Parameters

The following parameters are available in the `wordpress::cli` class.

##### `wpcli_url`

Data type: `Pattern['^http']`

http URL where to download the wpcli tool.

##### `wpcli_bin`

Data type: `Pattern['^/']`

The PATH where the wpcli tools is deployed.

##### `ensure`

Data type: `Enum['present','absent']`

The desirated state about wpcli tools. Valid values are 'present', 'absent'. Defaults to 'present'.

Default value: $wordpress::params::default_wpcli_ensure

### wordpress::core

use wpcli to download wordpress core, create tables in database and configure wordpress.

#### Parameters

The following parameters are available in the `wordpress::core` class.

##### `wpcli_bin`

Data type: `Pattern['^/']`

The PATH where the wpcli tools is deployed.

##### `settings`

Data type: `Wordpress::Settings`

Describes all availables settings in this module for all wordpress instances on this node. Defaults to empty hash.

Default value: {}

### wordpress::external_fact

deploy files to forge an external fact named 'wordpress'

#### Parameters

The following parameters are available in the `wordpress::external_fact` class.

##### `settings`

Data type: `Wordpress::Settings`

Describes all availables settings in this module for all wordpress instances on this node. Defaults to empty hash.

Default value: {}

### wordpress::params

set defaults values for some variables and parameters.

### wordpress::resource

download and manage resources aka plugins and themes.

#### Parameters

The following parameters are available in the `wordpress::resource` class.

##### `settings`

Data type: `Wordpress::Settings`

Describes all availables settings in this module for all wordpress instances on this node. Defaults to empty hash.

Default value: {}

##### `wpcli_bin`

Data type: `Pattern['^/']`

The PATH where the wpcli tools is deployed. Defaults to '/usr/local/bin/wp'.

